from __future__ import annotations
from typing import *
from .intervals import Interval
import scipy.stats as sps
from .ecdf import transform_eCDF_bundle, get_ecdf, eCDF_bundle


def imprecise_ecdf_sps(s: Interval) -> tuple[eCDF_bundle, eCDF_bundle]:
    """empirical cdf for interval valued data

    caveat:
        with the use of `sps.ecdf`, the probability value does not start from 0.

    returns:
        - left and right cdfs
        - pbox
    """
    b_l = transform_eCDF_bundle(sps.ecdf(s.lo))
    b_r = transform_eCDF_bundle(sps.ecdf(s.hi))

    return b_l, b_r


def imprecise_ecdf(s: Interval) -> tuple[eCDF_bundle, eCDF_bundle]:
    """empirical cdf for interval valued data

    returns:
        - left and right cdfs
        - pbox
    """
    b_l = eCDF_bundle(*get_ecdf(s.lo))
    b_r = eCDF_bundle(*get_ecdf(s.hi))

    return b_l, b_r



# * ---------------------helper functions  --------------------- *#
from __future__ import annotations
from typing import TYPE_CHECKING
import matplotlib.pyplot as plt

if TYPE_CHECKING:
    from .pba.pbox_abc import Pbox
    from .pba.dss import DempsterShafer


def inspect_un(x: any):
    """Inspect the any type of uncertain number x."""
    print(x.__repr__())
    x.display()


def env_helper(elements: list, env):
    """help visualise the envelope"""

    fig, ax = plt.subplots()

    env.plot(fill_color="salmon", ax=ax, bound_colors=["salmon", "salmon"], zorder=50)

    for p in elements:
        p.plot(ax=ax, zorder=100)



"""to verify the arithmetic operations on Frechet ops on a new vectorised implementation

hint: this verifies that new vectorised operations match the old reference implementation
"""

from pyuncertainnumber import pba
from pyuncertainnumber.pba.pbox_abc import inspect_pbox

a = pba.normal([4, 5], 1)  # positive
# b = pba.uniform([3, 4], [7, 8])  # positive

# a = pba.normal([1, 2], 1)  # straddles zero
b = pba.uniform([-3, -2], [3, 4])  # straddles 0


### + ###
c_ref_add = a + b
c_new_add = a.vec_add(b, dependency="f")
assert c_ref_add == c_new_add, "Addition operation not matching"

### - ###
c_ref_sub = a - b
c_new_sub = a.vec_sub(b, dependency="f")
assert c_ref_sub == c_new_sub, "Subtraction operation not matching"

### * ###
c_ref_mul = a * b
c_new_mul = a.vec_mul(b, dependency="f")
assert c_ref_mul == c_new_mul, "Multiplication operation not matching"

### / ###
# c_ref_div = a / b
# c_new_div = a.vec_div(b, dependency="f")
# assert c_ref_div == c_new_div, "Division operation not matching"

print("-------test over-------")
